from emod_api.demographics.Demographics import Demographics, Node

class GenericDemographics(Demographics):
    """
        This class is derived from emod_api.demographics' Demographics class so that we can set 
        certain defaults for Generic in construction. As we add other disease types, the 
        generalizations and speicfics will become clearer.
    """
    def __init__(self, nodes, idref="Gridded world grump2.5arcmin", base_file=None):
        super().__init__( nodes, idref, base_file )
        super().SetDefaultProperties()

def fromBasicNode(lat=0, lon=0, pop=1e6, name=1, forced_id=1):
    """
        This function creates a single-node GenericDemographics instance from the params you give it. 

        Args:
            lat: latitude (not really used)
            lon: longitude (not really used)
            pop: population. Defaults to 1 million.
            name: node name (not really used)
            forced_id: node id (not really used)

        Returns:
            GENERIC_SIM demographics instance which can be customized and/or written to file.
    """
    new_nodes = [ Node(lat=lat, lon=lon, pop=pop, name=name, forced_id=forced_id) ]
    return GenericDemographics(nodes=new_nodes)

