
import unittest

class GenericImportTests(unittest.TestCase):
    def setUp(self) -> None:
        self.expected_items = None
        self.found_items = None
        pass

    def verify_expected_items_present(self, namespace):
        self.found_items = dir(namespace)
        for item in self.expected_items:
            self.assertIn(
                item,
                self.found_items
            )

    def tearDown(self) -> None:
        pass

    def test_requirements(self):
        import emod_api
        import emodpy_generic
        import emodpy
        # Testing that we can import all requirements
        checks = [dir(package) for package in [emod_api, emodpy_generic, emodpy]]
        for package in checks:
            self.assertIn('__package__', package)

    def test_module_interventions_complex_import(self):
        from emodpy_generic.interventions import complex_import
        self.expected_items = [
            "ComplexImportationEvent"
        ]

        self.verify_expected_items_present(namespace=complex_import)
        pass

    def test_module_interventions_simple_sia(self):
        from emodpy_generic.interventions import simple_sia
        self.expected_items = [
            "SimpleSIA"
        ]

        self.verify_expected_items_present(namespace=simple_sia)
        pass


    def test_module_interventions_emergence(self):
        from emodpy_generic.interventions import emergence
        self.expected_items = [
            "basicEmergenceEvent"
        ]

        self.verify_expected_items_present(namespace=emergence)
        pass

    def test_module_interventions_polio_vaccine(self):
        from emodpy_generic.interventions import polio_vaccine
        self.expected_items = [
            "SimpleIPV1",
            "SimpleIPV2"
        ]

        self.verify_expected_items_present(namespace=polio_vaccine)
        pass

    def test_module_demographics(self):
        import emodpy_generic.demographics.GenericDemographics as demographics
        self.expected_items = [
            "GenericDemographics"
        ]

        self.verify_expected_items_present(namespace=demographics)
        pass


if __name__ == "__main__":
    unittest.main()
